@@ -41,6 +41,21 @@ test.nestedlist <- function()
 
 test.bad.list <- function()
 {
-	json <- "{\"a\": 123,}"
-	checkException( fromJSON( json ) )
-}
\ No newline at end of file
+	bad_json <- "{\"a\": 123,}"
+	x <- try( fromJSON( bad_json ), silent = TRUE )
+	checkTrue( any( class( x ) == "try-error" ) )
+}
+
+test.unsupported.sexp <- function()
+{
+	x <- fromJSON('{ "key":[ { "foo":"bar" }, { "bah":"baz" }] }')
+	correct <- list( key = list( list( foo = "bar" ), list( bah = "baz" ) ))
+	checkIdentical( x, correct )
+}
+
+test.rejected.comma <- function()
+{
+	bad_json = '{ "key":[ { "foo":"bar" }, { "bah":"baz" },] }'
+	x <- try( fromJSON( bad_json ), silent = TRUE )
+	checkTrue( any( class( x ) == "try-error" ) )
+}
